extras-buildsys/server Config.py,1.6,1.7 PackageJob.py,1.30,1.31

Daniel Williams (dcbw) fedora-extras-commits at redhat.com
Wed Sep 14 18:21:22 UTC 2005


Author: dcbw

Update of /cvs/fedora/extras-buildsys/server
In directory cvs-int.fedora.redhat.com:/tmp/cvs-serv22728/server

Modified Files:
	Config.py PackageJob.py 
Log Message:
2005-09-14  Dan Williams  <dcbw at redhat.com>

    * server/PackageJob.py
      server/Config.py
        - Rename "scratch" targets to "testing" targets to make their
            purpose clearer
        - Don't delete packages from the repodir if their target
            is a testing target




Index: Config.py
===================================================================
RCS file: /cvs/fedora/extras-buildsys/server/Config.py,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Config.py	9 Sep 2005 15:10:17 -0000	1.6
+++ Config.py	14 Sep 2005 18:21:20 -0000	1.7
@@ -202,7 +202,7 @@
         self.set_option("General", "distro", "fedora")
         self.set_option("General", "target", "development")
         self.set_option("General", "repo", "core")
-        self.set_option("General", "scratch", "no")
+        self.set_option("General", "testing", "no")
         self.set_option("General", "repo_script", "")
 
         self.add_section("Arches")


Index: PackageJob.py
===================================================================
RCS file: /cvs/fedora/extras-buildsys/server/PackageJob.py,v
retrieving revision 1.30
retrieving revision 1.31
diff -u -r1.30 -r1.31
--- PackageJob.py	14 Sep 2005 11:50:29 -0000	1.30
+++ PackageJob.py	14 Sep 2005 18:21:20 -0000	1.31
@@ -526,9 +526,9 @@
             msg = "%s\n-------------------------------------------------\n\n%s\n" % (msg, logtail)
             self.email_result(self.username, resultstring=msg, subject=subj)
 
             # Only non-scratch targets kill remaining jobs and file the entire
             # build when one archjob fails
-            if self._target_cfg.get_bool("General", "scratch") == False:
+            if self._target_cfg.get_bool("General", "testing") == False:
                 # Kill remaining jobs on other arches
                 self._kill_all_archjobs()
                 self._stage_failed(e.msg)
@@ -548,8 +548,8 @@
                     failed_jobs = failed_jobs + 1
 
                     # Normal jobs will just stop when a single archjob fails, but
                     # scratch targets don't kill the build when one fails.  However,
                     # even for scratch targets, we still want to notify the user if
                     # a particular arch fails.
                     if not job.failure_noticed():
                         job.set_failure_noticed()
@@ -566,8 +566,8 @@
         self._archjobs_lock.release()
 
         if completed_jobs == len(self.archjobs):
-            # Scratch targets don't contribute packages to the repo
-            if self._target_cfg.get_bool("General", "scratch") == True:
+            # Testing targets don't contribute packages to the repo
+            if self._target_cfg.get_bool("General", "testing") == True:
                 if failed_jobs > 0:
                     self._stage_failed("Job failed on one or more architectures.")
                 else:
@@ -592,6 +592,12 @@
         if not self.result_dir or not self.srpm_http_path:
             return
 
+        # If its a testing target, we keep the RPMs around since they don't
+        # get copied to the repository, they only live in the repodir
+        testing_target = self._target_cfg.get_bool("General", "testing")
+        if self.result == 'success' and testing_target == True:
+            return
+
         srpm_file = os.path.join(self.result_dir, os.path.basename(self.srpm_http_path))
 
         # Delete any RPMs in the arch dirs
@@ -526,9 +526,9 @@
             self.email_result(self.username, resultstring=msg, subject=subj)
 
-            # Only non-scratch targets kill remaining jobs and file the entire
+            # Only non-testing targets kill remaining jobs and file the entire
             # build when one archjob fails
@@ -548,8 +548,8 @@
 
                     # Normal jobs will just stop when a single archjob fails, but
-                    # scratch targets don't kill the build when one fails.  However,
-                    # even for scratch targets, we still want to notify the user if
+                    # testing targets don't kill the build when one fails.  However,
+                    # even for testing targets, we still want to notify the user if
                     # a particular arch fails.
                     if not job.failure_noticed():




More information about the fedora-extras-commits mailing list